# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/stock_security_product.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n%v1/rules/stock_security_product.proto\x12\x30pro.omni.oms.api.v1.rules.stock_security_product\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/protobuf/struct.proto"\xe0\x01\n\x14StockSecurityProduct\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12%\n\x04skus\x18\x05 \x03(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06\x61\x63tive\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x07 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xac\x01\n!StockSecurityProductCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12%\n\x04skus\x18\x04 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x36\n\x07\x63ontext\x18\x05 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd7\x01\n"StockSecurityProductCreateResponse\x12\x66\n\x16stock_security_product\x18\x01 \x01(\x0b\x32\x46.pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProduct\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xfd\x02\n\x1fStockSecurityProductReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x91\x02\n StockSecurityProductReadResponse\x12g\n\x17stock_security_products\x18\x01 \x03(\x0b\x32\x46.pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProduct\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xc3\x01\n!StockSecurityProductUpdateRequest\x12\x66\n\x16stock_security_product\x18\x01 \x01(\x0b\x32\x46.pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProduct\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd7\x01\n"StockSecurityProductUpdateResponse\x12\x66\n\x16stock_security_product\x18\x01 \x01(\x0b\x32\x46.pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProduct\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"g\n!StockSecurityProductDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"o\n"StockSecurityProductDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xc7\x06\n\x1bStockSecurityProductService\x12\xc9\x01\n\x1aStockSecurityProductCreate\x12S.pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductCreateRequest\x1aT.pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductCreateResponse"\x00\x12\xc3\x01\n\x18StockSecurityProductRead\x12Q.pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductReadRequest\x1aR.pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductReadResponse"\x00\x12\xc9\x01\n\x1aStockSecurityProductUpdate\x12S.pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductUpdateRequest\x1aT.pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductUpdateResponse"\x00\x12\xc9\x01\n\x1aStockSecurityProductDelete\x12S.pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductDeleteRequest\x1aT.pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.stock_security_product_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_STOCKSECURITYPRODUCT"]._serialized_start = 173
    _globals["_STOCKSECURITYPRODUCT"]._serialized_end = 397
    _globals["_STOCKSECURITYPRODUCTCREATEREQUEST"]._serialized_start = 400
    _globals["_STOCKSECURITYPRODUCTCREATEREQUEST"]._serialized_end = 572
    _globals["_STOCKSECURITYPRODUCTCREATERESPONSE"]._serialized_start = 575
    _globals["_STOCKSECURITYPRODUCTCREATERESPONSE"]._serialized_end = 790
    _globals["_STOCKSECURITYPRODUCTREADREQUEST"]._serialized_start = 793
    _globals["_STOCKSECURITYPRODUCTREADREQUEST"]._serialized_end = 1174
    _globals["_STOCKSECURITYPRODUCTREADRESPONSE"]._serialized_start = 1177
    _globals["_STOCKSECURITYPRODUCTREADRESPONSE"]._serialized_end = 1450
    _globals["_STOCKSECURITYPRODUCTUPDATEREQUEST"]._serialized_start = 1453
    _globals["_STOCKSECURITYPRODUCTUPDATEREQUEST"]._serialized_end = 1648
    _globals["_STOCKSECURITYPRODUCTUPDATERESPONSE"]._serialized_start = 1651
    _globals["_STOCKSECURITYPRODUCTUPDATERESPONSE"]._serialized_end = 1866
    _globals["_STOCKSECURITYPRODUCTDELETEREQUEST"]._serialized_start = 1868
    _globals["_STOCKSECURITYPRODUCTDELETEREQUEST"]._serialized_end = 1971
    _globals["_STOCKSECURITYPRODUCTDELETERESPONSE"]._serialized_start = 1973
    _globals["_STOCKSECURITYPRODUCTDELETERESPONSE"]._serialized_end = 2084
    _globals["_STOCKSECURITYPRODUCTSERVICE"]._serialized_start = 2087
    _globals["_STOCKSECURITYPRODUCTSERVICE"]._serialized_end = 2926
# @@protoc_insertion_point(module_scope)
