# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import stock_security_product_pb2 as v1_dot_rules_dot_stock__security__product__pb2


class StockSecurityProductServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StockSecurityProductCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductService/StockSecurityProductCreate",
            request_serializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductCreateResponse.FromString,
        )
        self.StockSecurityProductRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductService/StockSecurityProductRead",
            request_serializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductReadResponse.FromString,
        )
        self.StockSecurityProductUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductService/StockSecurityProductUpdate",
            request_serializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductUpdateResponse.FromString,
        )
        self.StockSecurityProductDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductService/StockSecurityProductDelete",
            request_serializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductDeleteResponse.FromString,
        )


class StockSecurityProductServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def StockSecurityProductCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StockSecurityProductRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StockSecurityProductUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StockSecurityProductDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_StockSecurityProductServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "StockSecurityProductCreate": grpc.unary_unary_rpc_method_handler(
            servicer.StockSecurityProductCreate,
            request_deserializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductCreateResponse.SerializeToString,
        ),
        "StockSecurityProductRead": grpc.unary_unary_rpc_method_handler(
            servicer.StockSecurityProductRead,
            request_deserializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductReadResponse.SerializeToString,
        ),
        "StockSecurityProductUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.StockSecurityProductUpdate,
            request_deserializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductUpdateResponse.SerializeToString,
        ),
        "StockSecurityProductDelete": grpc.unary_unary_rpc_method_handler(
            servicer.StockSecurityProductDelete,
            request_deserializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class StockSecurityProductService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def StockSecurityProductCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductService/StockSecurityProductCreate",
            v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductCreateRequest.SerializeToString,
            v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def StockSecurityProductRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductService/StockSecurityProductRead",
            v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductReadRequest.SerializeToString,
            v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def StockSecurityProductUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductService/StockSecurityProductUpdate",
            v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductUpdateRequest.SerializeToString,
            v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def StockSecurityProductDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.stock_security_product.StockSecurityProductService/StockSecurityProductDelete",
            v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductDeleteRequest.SerializeToString,
            v1_dot_rules_dot_stock__security__product__pb2.StockSecurityProductDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
