# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/utilities/document_type.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n v1/utilities/document_type.proto\x12+pro.omni.oms.api.v1.utilities.document_type\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xdd\x01\n\x0c\x44ocumentType\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\x05\x12*\n\x06is_vat\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x06\x61\x63tive\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x07 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xd2\x01\n\x16\x44ocumentTypeAddRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0c\n\x04size\x18\x03 \x01(\x05\x12*\n\x06is_vat\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x06\x61\x63tive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x07\x63ontext\x18\x06 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb6\x01\n\x17\x44ocumentTypeAddResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12P\n\rdocument_type\x18\x02 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.document_type.DocumentType"\xf5\x02\n\x17\x44ocumentTypeReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xf3\x01\n\x18\x44ocumentTypeReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12Q\n\x0e\x64ocument_types\x18\x03 \x03(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.document_type.DocumentType"\xa5\x01\n\x19\x44ocumentTypeUpdateRequest\x12P\n\rdocument_type\x18\x01 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.document_type.DocumentType\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb9\x01\n\x1a\x44ocumentTypeUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12P\n\rdocument_type\x18\x02 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.document_type.DocumentType"_\n\x19\x44ocumentTypeDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"g\n\x1a\x44ocumentTypeDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xae\x05\n\x13\x44ocumentTypeService\x12\x9e\x01\n\x0f\x44ocumentTypeAdd\x12\x43.pro.omni.oms.api.v1.utilities.document_type.DocumentTypeAddRequest\x1a\x44.pro.omni.oms.api.v1.utilities.document_type.DocumentTypeAddResponse"\x00\x12\xa1\x01\n\x10\x44ocumentTypeRead\x12\x44.pro.omni.oms.api.v1.utilities.document_type.DocumentTypeReadRequest\x1a\x45.pro.omni.oms.api.v1.utilities.document_type.DocumentTypeReadResponse"\x00\x12\xa7\x01\n\x12\x44ocumentTypeUpdate\x12\x46.pro.omni.oms.api.v1.utilities.document_type.DocumentTypeUpdateRequest\x1aG.pro.omni.oms.api.v1.utilities.document_type.DocumentTypeUpdateResponse"\x00\x12\xa7\x01\n\x12\x44ocumentTypeDelete\x12\x46.pro.omni.oms.api.v1.utilities.document_type.DocumentTypeDeleteRequest\x1aG.pro.omni.oms.api.v1.utilities.document_type.DocumentTypeDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.utilities.document_type_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_DOCUMENTTYPE"]._serialized_start = 133
    _globals["_DOCUMENTTYPE"]._serialized_end = 354
    _globals["_DOCUMENTTYPEADDREQUEST"]._serialized_start = 357
    _globals["_DOCUMENTTYPEADDREQUEST"]._serialized_end = 567
    _globals["_DOCUMENTTYPEADDRESPONSE"]._serialized_start = 570
    _globals["_DOCUMENTTYPEADDRESPONSE"]._serialized_end = 752
    _globals["_DOCUMENTTYPEREADREQUEST"]._serialized_start = 755
    _globals["_DOCUMENTTYPEREADREQUEST"]._serialized_end = 1128
    _globals["_DOCUMENTTYPEREADRESPONSE"]._serialized_start = 1131
    _globals["_DOCUMENTTYPEREADRESPONSE"]._serialized_end = 1374
    _globals["_DOCUMENTTYPEUPDATEREQUEST"]._serialized_start = 1377
    _globals["_DOCUMENTTYPEUPDATEREQUEST"]._serialized_end = 1542
    _globals["_DOCUMENTTYPEUPDATERESPONSE"]._serialized_start = 1545
    _globals["_DOCUMENTTYPEUPDATERESPONSE"]._serialized_end = 1730
    _globals["_DOCUMENTTYPEDELETEREQUEST"]._serialized_start = 1732
    _globals["_DOCUMENTTYPEDELETEREQUEST"]._serialized_end = 1827
    _globals["_DOCUMENTTYPEDELETERESPONSE"]._serialized_start = 1829
    _globals["_DOCUMENTTYPEDELETERESPONSE"]._serialized_end = 1932
    _globals["_DOCUMENTTYPESERVICE"]._serialized_start = 1935
    _globals["_DOCUMENTTYPESERVICE"]._serialized_end = 2621
# @@protoc_insertion_point(module_scope)
