# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/utilities/model.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x18v1/utilities/model.proto\x12#pro.omni.oms.api.v1.utilities.model\x1a\x11\x63ommon/base.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xaf\x02\n\x05Model\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0cmicroservice\x18\x02 \x01(\t\x12\x18\n\x10persistence_type\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0c\n\x04\x63ode\x18\x05 \x01(\t\x12\x12\n\nclass_name\x18\x06 \x01(\t\x12\x11\n\thash_code\x18\x07 \x01(\t\x12:\n\x06\x66ields\x18\x08 \x03(\x0b\x32*.pro.omni.oms.api.v1.utilities.model.Field\x12*\n\x06\x61\x63tive\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\n \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xf8\x01\n\x05\x46ield\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\x12\x0c\n\x04size\x18\x05 \x01(\x05\x12,\n\x08required\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12)\n\x08relation\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06widget\x18\x08 \x01(\t\x12\x0c\n\x04view\x18\t \x01(\t\x12+\n\x07options\x18\n \x01(\x0b\x32\x1a.google.protobuf.ListValue"\xfb\x01\n\x12ModelCreateRequest\x12\x14\n\x0cmicroservice\x18\x01 \x01(\t\x12\x18\n\x10persistence_type\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\x12\x12\n\nclass_name\x18\x05 \x01(\t\x12\x11\n\thash_code\x18\x06 \x01(\t\x12:\n\x06\x66ields\x18\x07 \x03(\x0b\x32*.pro.omni.oms.api.v1.utilities.model.Field\x12\x36\n\x07\x63ontext\x18\x08 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9b\x01\n\x13ModelCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\x05model\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.utilities.model.Model"\xee\x02\n\x10ModelReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd5\x01\n\x11ModelReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12:\n\x06models\x18\x03 \x03(\x0b\x32*.pro.omni.oms.api.v1.utilities.model.Model"\x87\x01\n\x12ModelUpdateRequest\x12\x39\n\x05model\x18\x01 \x01(\x0b\x32*.pro.omni.oms.api.v1.utilities.model.Model\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9b\x01\n\x13ModelUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\x05model\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.utilities.model.Model"X\n\x12ModelDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"`\n\x13ModelDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\x9c\x04\n\rModelsService\x12\x82\x01\n\x0bModelCreate\x12\x37.pro.omni.oms.api.v1.utilities.model.ModelCreateRequest\x1a\x38.pro.omni.oms.api.v1.utilities.model.ModelCreateResponse"\x00\x12|\n\tModelRead\x12\x35.pro.omni.oms.api.v1.utilities.model.ModelReadRequest\x1a\x36.pro.omni.oms.api.v1.utilities.model.ModelReadResponse"\x00\x12\x82\x01\n\x0bModelUpdate\x12\x37.pro.omni.oms.api.v1.utilities.model.ModelUpdateRequest\x1a\x38.pro.omni.oms.api.v1.utilities.model.ModelUpdateResponse"\x00\x12\x82\x01\n\x0bModelDelete\x12\x37.pro.omni.oms.api.v1.utilities.model.ModelDeleteRequest\x1a\x38.pro.omni.oms.api.v1.utilities.model.ModelDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.utilities.model_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_MODEL"]._serialized_start = 147
    _globals["_MODEL"]._serialized_end = 450
    _globals["_FIELD"]._serialized_start = 453
    _globals["_FIELD"]._serialized_end = 701
    _globals["_MODELCREATEREQUEST"]._serialized_start = 704
    _globals["_MODELCREATEREQUEST"]._serialized_end = 955
    _globals["_MODELCREATERESPONSE"]._serialized_start = 958
    _globals["_MODELCREATERESPONSE"]._serialized_end = 1113
    _globals["_MODELREADREQUEST"]._serialized_start = 1116
    _globals["_MODELREADREQUEST"]._serialized_end = 1482
    _globals["_MODELREADRESPONSE"]._serialized_start = 1485
    _globals["_MODELREADRESPONSE"]._serialized_end = 1698
    _globals["_MODELUPDATEREQUEST"]._serialized_start = 1701
    _globals["_MODELUPDATEREQUEST"]._serialized_end = 1836
    _globals["_MODELUPDATERESPONSE"]._serialized_start = 1839
    _globals["_MODELUPDATERESPONSE"]._serialized_end = 1994
    _globals["_MODELDELETEREQUEST"]._serialized_start = 1996
    _globals["_MODELDELETEREQUEST"]._serialized_end = 2084
    _globals["_MODELDELETERESPONSE"]._serialized_start = 2086
    _globals["_MODELDELETERESPONSE"]._serialized_end = 2182
    _globals["_MODELSSERVICE"]._serialized_start = 2185
    _globals["_MODELSSERVICE"]._serialized_end = 2725
# @@protoc_insertion_point(module_scope)
