# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import calendar_pb2 as v1_dot_rules_dot_calendar__pb2


class CalendarServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CalendarCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.calendar.CalendarService/CalendarCreate",
            request_serializer=v1_dot_rules_dot_calendar__pb2.CalendarCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_calendar__pb2.CalendarCreateResponse.FromString,
        )
        self.CalendarRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.calendar.CalendarService/CalendarRead",
            request_serializer=v1_dot_rules_dot_calendar__pb2.CalendarReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_calendar__pb2.CalendarReadResponse.FromString,
        )
        self.CalendarUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.calendar.CalendarService/CalendarUpdate",
            request_serializer=v1_dot_rules_dot_calendar__pb2.CalendarUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_calendar__pb2.CalendarUpdateResponse.FromString,
        )
        self.CalendarDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.calendar.CalendarService/CalendarDelete",
            request_serializer=v1_dot_rules_dot_calendar__pb2.CalendarDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_calendar__pb2.CalendarDeleteResponse.FromString,
        )


class CalendarServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CalendarCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CalendarRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CalendarUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CalendarDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_CalendarServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "CalendarCreate": grpc.unary_unary_rpc_method_handler(
            servicer.CalendarCreate,
            request_deserializer=v1_dot_rules_dot_calendar__pb2.CalendarCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_calendar__pb2.CalendarCreateResponse.SerializeToString,
        ),
        "CalendarRead": grpc.unary_unary_rpc_method_handler(
            servicer.CalendarRead,
            request_deserializer=v1_dot_rules_dot_calendar__pb2.CalendarReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_calendar__pb2.CalendarReadResponse.SerializeToString,
        ),
        "CalendarUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.CalendarUpdate,
            request_deserializer=v1_dot_rules_dot_calendar__pb2.CalendarUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_calendar__pb2.CalendarUpdateResponse.SerializeToString,
        ),
        "CalendarDelete": grpc.unary_unary_rpc_method_handler(
            servicer.CalendarDelete,
            request_deserializer=v1_dot_rules_dot_calendar__pb2.CalendarDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_calendar__pb2.CalendarDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.calendar.CalendarService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class CalendarService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CalendarCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.calendar.CalendarService/CalendarCreate",
            v1_dot_rules_dot_calendar__pb2.CalendarCreateRequest.SerializeToString,
            v1_dot_rules_dot_calendar__pb2.CalendarCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CalendarRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.calendar.CalendarService/CalendarRead",
            v1_dot_rules_dot_calendar__pb2.CalendarReadRequest.SerializeToString,
            v1_dot_rules_dot_calendar__pb2.CalendarReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CalendarUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.calendar.CalendarService/CalendarUpdate",
            v1_dot_rules_dot_calendar__pb2.CalendarUpdateRequest.SerializeToString,
            v1_dot_rules_dot_calendar__pb2.CalendarUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CalendarDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.calendar.CalendarService/CalendarDelete",
            v1_dot_rules_dot_calendar__pb2.CalendarDeleteRequest.SerializeToString,
            v1_dot_rules_dot_calendar__pb2.CalendarDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
